@@ -23,18 +23,12 @@
 
 #include <QResizeEvent>
 #include <QWheelEvent>
+#include <QtMath>
 
 #include <KLocalizedString>
 
 
-// this function is used in executer and canvas:
-#define ROUND2INT(x) ( (x) >= 0 ? (int)( (x) + .5 ) : (int)( (x) - .5 ) )
 
-#ifndef M_PI 
-#define M_PI 3.14159265358979323846264338327950288419717
-#endif
-
-const double DegToRad = M_PI / 180.0;
 int kTurtleZValue = 1;
 int kCanvasFrameZValue = -10000;
 int kCanvasMargin = 20;
@@ -116,9 +110,9 @@ void Canvas::resizeEvent(QResizeEvent* event)
 
 QColor Canvas::rgbDoublesToColor(double r, double g, double b)
 {
-	return QColor(qMin(qMax((int)r, 0), 255),
-	              qMin(qMax((int)g, 0), 255),
-	              qMin(qMax((int)b, 0), 255));
+	return QColor(qMin(qMax(static_cast<int>(r), 0), 255),
+			qMin(qMax(static_cast<int>(g), 0), 255),
+			qMin(qMax(static_cast<int>(b), 0), 255));
 }
 
 void Canvas::drawLine(double x1, double y1, double x2, double y2)
@@ -143,16 +137,16 @@ void Canvas::slotClear()
 
 void Canvas::slotForward(double x)
 {
-	double x2 = turtle->pos().x() + (x * std::sin(turtle->angle() * DegToRad));
-	double y2 = turtle->pos().y() - (x * std::cos(turtle->angle() * DegToRad));
+	double x2 = turtle->pos().x() + (x * std::sin(qDegreesToRadians(turtle->angle())));
+	double y2 = turtle->pos().y() - (x * std::cos(qDegreesToRadians(turtle->angle())));
 	drawLine(turtle->pos().x(), turtle->pos().y(), x2, y2);
 	slotGo(x2, y2);
 }
 
 void Canvas::slotBackward(double x)
 {
-	double x2 = turtle->pos().x() - ( x * std::sin(turtle->angle() * DegToRad) );
-	double y2 = turtle->pos().y() + ( x * std::cos(turtle->angle() * DegToRad) );
+	double x2 = turtle->pos().x() - ( x * std::sin(qDegreesToRadians(turtle->angle())));
+	double y2 = turtle->pos().y() + ( x * std::cos(qDegreesToRadians(turtle->angle())));
 	drawLine(turtle->pos().x(), turtle->pos().y(), x2, y2);
 	slotGo(x2, y2);
 }
@@ -164,7 +158,7 @@ void Canvas::slotCenter()
 
 void Canvas::slotPenWidth(double width)
 {
-	int w = qMax(ROUND2INT(width), 0);
+	int w = qMax(static_cast<int>(round(width)), 0);
 	if (w == 0) {
 		penWidthIsZero = true;
 		return;
@@ -180,7 +174,7 @@ void Canvas::slotPenWidth(double width)
 void Canvas::slotPenColor(double r, double g, double b)
 {
 	pen->setColor(rgbDoublesToColor(r, g, b));
-	textColor.setRgb((int)r, (int)g, (int)b);
+	textColor.setRgb(static_cast<int>(r), static_cast<int>(g), static_cast<int>(b));
 }
 
 void Canvas::slotCanvasColor(double r, double g, double b)
@@ -225,7 +219,7 @@ void Canvas::slotReset()
 
 void Canvas::wheelEvent(QWheelEvent *event)
 {
-	scaleView(std::pow((double)2.0, -event->delta() / 240.0));
+	scaleView(std::pow(static_cast<double>(2.0), -event->delta() / 240.0));
 }
 
 void Canvas::scaleView(double scaleFactor)
